===============================
Argos
===============================


Argos Panoptes data inspector.

Requires: PyQtGraph (http://www.pyqtgraph.org/).

For more info, see: https://github.com/titusjan/argos
